@@ -15,13 +15,15 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 import string
+from difflib import get_close_matches
 
+import discord
 from discord.ext import commands
 
 from sciolyid.data import (
     database,
     get_aliases,
-    get_wiki_url,
+    format_wiki_url,
     logger,
     possible_words,
     prompts,
@@ -101,12 +103,8 @@ class Check(commands.Cog):
                 if not database.exists(f"race.data:{ctx.channel.id}")
                 else f"**{ctx.author.mention}**, you are correct! The image was **{current_item}**."
             )
-            url = get_wiki_url(ctx, current_item)
-            await ctx.send(
-                url
-                if not database.exists(f"race.data:{ctx.channel.id}")
-                else f"<{url}>"
-            )  # sends wiki page
+            url = format_wiki_url(ctx, current_item)
+            await ctx.send(url)  # sends wiki page
             score_increment(ctx, 1)
             if database.exists(f"race.data:{ctx.channel.id}"):
 
@@ -152,9 +150,23 @@ class Check(commands.Cog):
                 database.hset(f"channel:{ctx.channel.id}", "item", "")
                 database.hset(f"channel:{ctx.channel.id}", "answered", "1")
                 await ctx.send("Sorry, the image was actually " + current_item + ".")
-                url = get_wiki_url(ctx, current_item)
+                url = format_wiki_url(ctx, current_item)
                 await ctx.send(url)
 
+    async def race_autocheck(self, message: discord.Message):
+        if not database.exists(f"race.data:{message.channel.id}"):
+            return
+        if len(get_close_matches(message.content.strip().lower(), possible_words)) != 0:
+            logger.info("race autocheck found: checking")
+            ctx = commands.Context(
+                message=message,
+                bot=self.bot,
+                prefix="race-autocheck",
+            )
+            await self.check(ctx, arg=message.content)
+
 
 def setup(bot):
-    bot.add_cog(Check(bot))
+    cog = Check(bot)
+    bot.add_message_handler(cog.race_autocheck)
+    bot.add_cog(cog)
