@@ -60,6 +60,7 @@ optional: Dict[str, Any] = {
     "short_id_type": "",  # short (usually 1 letter) form of id_type, used as alias for the pic command
     "invite": "This bot is currently not available outside the support server.",  # bot server invite link
     "authors": "person_v1.32, hmmm, and EraserBird",  # creator names
+    "extra_about_fields": None,  # list of dicts containing keys "name" and "value" to be added to the botinfo command
     # "id_groups": True,  # true/false - if you want to be able to select certain groups of items to id, set automatically from "category_name"
     "category_name": None,  # space thing, bird order, muscle group - what you are splitting groups by
     "category_aliases": {},  # aliases for categories
@@ -92,6 +93,7 @@ web_optional: Dict[str, Any] = {
     "frontend_url_env": "FRONTEND_URL",  # name of environment variable for frontend url
     "client_secret_env": "DISCORD_CLIENT_SECRET",  # name of environment variable for discord client secret
     "discord_webhook_env": "DISCORD_WEBHOOK_URL",  # webhook url for discord notification log
+    "discord_webhook_disable": [],  # types of webhooks to disable ("add", "verify", "valid", "error")
     "verification_server": None,  # invite to special discord server for people adding images, default to support server
     "disable_upload": False,  # disable user uploads
     "disable_validation": False,  # disable validation
